pub struct AccessSessionSparkApplicationSqlSparkPlanGraphResponse {
pub spark_plan_graph: Option<SparkPlanGraph>,
}Expand description
SparkPlanGraph for a Spark Application execution limited to maximum 10000 clusters.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
spark_plan_graph: Option<SparkPlanGraph>SparkPlanGraph for a Spark Application execution.