pub struct AnalyzeBatchRequest {
pub request_id: Option<String>,
pub requestor_id: Option<String>,
}Expand description
A request to analyze a batch workload.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations batches analyze projects (request)
Fields
request_id: Option<String>Optional. A unique ID used to identify the request. If the service receives two AnalyzeBatchRequest (http://cloud/dataproc/docs/reference/rpc/google.cloud.dataproc.v1#google.cloud.dataproc.v1.AnalyzeBatchRequest)s with the same request_id, the second request is ignored and the Operation that corresponds to the first request created and stored in the backend is returned.Recommendation: Set this value to a UUID (https://en.wikipedia.org/wiki/Universally_unique_identifier).The value must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 40 characters.
requestor_id: Option<String>Optional. The requestor ID is used to identify if the request comes from a GCA investigation or the old Ask Gemini Experience.