pub struct HadoopJob {
pub archive_uris: Option<Vec<String>>,
pub args: Option<Vec<String>>,
pub file_uris: Option<Vec<String>>,
pub jar_file_uris: Option<Vec<String>>,
pub logging_config: Option<LoggingConfig>,
pub main_class: Option<String>,
pub main_jar_file_uri: Option<String>,
pub properties: Option<HashMap<String, String>>,
}Expand description
A Dataproc job for running Apache Hadoop MapReduce (https://hadoop.apache.org/docs/current/hadoop-mapreduce-client/hadoop-mapreduce-client-core/MapReduceTutorial.html) jobs on Apache Hadoop YARN (https://hadoop.apache.org/docs/r2.7.1/hadoop-yarn/hadoop-yarn-site/YARN.html).
This type is not used in any activity, and only used as part of another schema.
Fields
archive_uris: Option<Vec<String>>Optional. HCFS URIs of archives to be extracted in the working directory of Hadoop drivers and tasks. Supported file types: .jar, .tar, .tar.gz, .tgz, or .zip.
args: Option<Vec<String>>Optional. The arguments to pass to the driver. Do not include arguments, such as -libjars or -Dfoo=bar, that can be set as job properties, since a collision might occur that causes an incorrect job submission.
file_uris: Option<Vec<String>>Optional. HCFS (Hadoop Compatible Filesystem) URIs of files to be copied to the working directory of Hadoop drivers and distributed tasks. Useful for naively parallel tasks.
jar_file_uris: Option<Vec<String>>Optional. Jar file URIs to add to the CLASSPATHs of the Hadoop driver and tasks.
logging_config: Option<LoggingConfig>Optional. The runtime log config for job execution.
main_class: Option<String>The name of the driver’s main class. The jar file containing the class must be in the default CLASSPATH or specified in jar_file_uris.
main_jar_file_uri: Option<String>The HCFS URI of the jar file containing the main class. Examples: ‘gs://foo-bucket/analytics-binaries/extract-useful-metrics-mr.jar’ ‘hdfs:/tmp/test-samples/custom-wordcount.jar’ ‘file:///home/usr/lib/hadoop-mapreduce/hadoop-mapreduce-examples.jar’
properties: Option<HashMap<String, String>>Optional. A mapping of property names to values, used to configure Hadoop. Properties that conflict with values set by the Dataproc API might be overwritten. Can include properties set in /etc/hadoop/conf/*-site and classes in user code.