pub struct SearchSparkApplicationExecutorsResponse {
pub next_page_token: Option<String>,
pub spark_application_executors: Option<Vec<ExecutorSummary>>,
}Expand description
List of Executors associated with a Spark Application.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent SearchSparkApplicationExecutorsListRequest.
spark_application_executors: Option<Vec<ExecutorSummary>>Details about executors used by the application.