pub struct SearchSparkApplicationStageAttemptsResponse {
pub next_page_token: Option<String>,
pub spark_application_stage_attempts: Option<Vec<StageData>>,
}Expand description
A list of Stage Attempts for a Stage of a Spark Application.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListSparkApplicationStageAttemptsRequest.
spark_application_stage_attempts: Option<Vec<StageData>>Output only. Data corresponding to a stage attempts