pub struct SpeculationStageSummary {
pub num_active_tasks: Option<i32>,
pub num_completed_tasks: Option<i32>,
pub num_failed_tasks: Option<i32>,
pub num_killed_tasks: Option<i32>,
pub num_tasks: Option<i32>,
pub stage_attempt_id: Option<i32>,
pub stage_id: Option<i64>,
}Expand description
Details of the speculation task when speculative execution is enabled.
This type is not used in any activity, and only used as part of another schema.
Fields
num_active_tasks: Option<i32>no description provided
num_completed_tasks: Option<i32>no description provided
num_failed_tasks: Option<i32>no description provided
num_killed_tasks: Option<i32>no description provided
num_tasks: Option<i32>no description provided
stage_attempt_id: Option<i32>no description provided
stage_id: Option<i64>no description provided