pub struct SummarizeSessionSparkApplicationStageAttemptTasksResponse {
pub stage_attempt_tasks_summary: Option<StageAttemptTasksSummary>,
}Expand description
Summary of tasks for a Spark Application stage attempt.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
stage_attempt_tasks_summary: Option<StageAttemptTasksSummary>Summary of tasks for a Spark Application Stage Attempt