pub struct SummarizeSparkApplicationStagesResponse {
pub stages_summary: Option<StagesSummary>,
}Expand description
Summary of a Spark Application stages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
stages_summary: Option<StagesSummary>Summary of a Spark Application Stages