Struct google_dataproc1::AcceleratorConfig
source · pub struct AcceleratorConfig {
pub accelerator_count: Option<i32>,
pub accelerator_type_uri: Option<String>,
}Expand description
Specifies the type and number of accelerator cards attached to the instances of an instance group (see GPUs on Compute Engine).
This type is not used in any activity, and only used as part of another schema.
Fields
accelerator_count: Option<i32>The number of the accelerator cards of this type exposed to this instance.
accelerator_type_uri: Option<String>Full or partial URI of the accelerator type resource to expose to this instance. See Google Compute Engine AcceleratorTypes( /compute/docs/reference/beta/acceleratorTypes)