Struct google_dataproc1::DiskConfig
source · pub struct DiskConfig {
pub num_local_ssds: Option<i32>,
pub boot_disk_size_gb: Option<i32>,
}Expand description
Specifies the config of disk options for a group of VM instances.
This type is not used in any activity, and only used as part of another schema.
Fields
num_local_ssds: Option<i32>Optional. Number of attached SSDs, from 0 to 4 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS (https://hadoop.apache.org/docs/r1.2.1/hdfs_user_guide.html) data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries.
boot_disk_size_gb: Option<i32>Optional. Size in GB of the boot disk (default is 500GB).