Struct google_dataproc1::GceClusterConfig

source ·
pub struct GceClusterConfig {
    pub internal_ip_only: Option<bool>,
    pub network_uri: Option<String>,
    pub tags: Option<Vec<String>>,
    pub service_account: Option<String>,
    pub zone_uri: Option<String>,
    pub subnetwork_uri: Option<String>,
    pub service_account_scopes: Option<Vec<String>>,
    pub metadata: Option<HashMap<String, String>>,
}
Common config settings for resources of Google Compute Engine cluster instances, applicable to all instances in the cluster.

This type is not used in any activity, and only used as part of another schema.

Fields

internal_ip_only: Option<bool>

Optional. If true, all instances in the cluster will only have internal IP addresses. By default, clusters are not restricted to internal IP addresses, and will have ephemeral external IP addresses assigned to each instance. This internal_ip_only restriction can only be enabled for subnetwork enabled networks, and all off-cluster dependencies must be configured to be accessible without external IP addresses.

network_uri: Option<String>

Optional. The Google Compute Engine network to be used for machine communications. Cannot be specified with subnetwork_uri. If neither network_uri nor subnetwork_uri is specified, the “default” network of the project is used, if it exists. Cannot be a “Custom Subnet Network” (see Using Subnetworks for more information). Example: https://www.googleapis.com/compute/v1/projects/[project_id]/regions/global/default.

tags: Option<Vec<String>>

The Google Compute Engine tags to add to all instances (see Tagging instances).

service_account: Option<String>

Optional. The service account of the instances. Defaults to the default Google Compute Engine service account. Custom service accounts need permissions equivalent to the folloing IAM roles: roles/logging.logWriter roles/storage.objectAdmin(see https://cloud.google.com/compute/docs/access/service-accounts#custom_service_accounts for more information). Example: [account_id]@[project_id].iam.gserviceaccount.com

zone_uri: Option<String>

Required. The zone where the Google Compute Engine cluster will be located. Example: https://www.googleapis.com/compute/v1/projects/[project_id]/zones/[zone].

subnetwork_uri: Option<String>

Optional. The Google Compute Engine subnetwork to be used for machine communications. Cannot be specified with network_uri. Example: https://www.googleapis.com/compute/v1/projects/[project_id]/regions/us-east1/sub0.

service_account_scopes: Option<Vec<String>>

Optional. The URIs of service account scopes to be included in Google Compute Engine instances. The following base set of scopes is always included: https://www.googleapis.com/auth/cloud.useraccounts.readonly https://www.googleapis.com/auth/devstorage.read_write https://www.googleapis.com/auth/logging.writeIf no scopes are specified, the following defaults are also provided: https://www.googleapis.com/auth/bigquery https://www.googleapis.com/auth/bigtable.admin.table https://www.googleapis.com/auth/bigtable.data https://www.googleapis.com/auth/devstorage.full_control

metadata: Option<HashMap<String, String>>

The Google Compute Engine metadata entries to add to all instances (see Project and instance metadata (https://cloud.google.com/compute/docs/storing-retrieving-metadata#project_and_instance_metadata)).