Struct google_dataproc1::JobReference
source · pub struct JobReference {
pub project_id: Option<String>,
pub job_id: Option<String>,
}Expand description
Encapsulates the full scoping used to reference a job.
This type is not used in any activity, and only used as part of another schema.
Fields
project_id: Option<String>Required. The ID of the Google Cloud Platform project that the job belongs to.
job_id: Option<String>Optional. The job ID, which must be unique within the project. The job ID is generated by the server upon job submission or provided by the user as a means to perform retries without creating duplicate jobs. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), or hyphens (-). The maximum length is 100 characters.