Struct google_dataproc1::JobScheduling
source · pub struct JobScheduling {
pub max_failures_per_hour: Option<i32>,
}Expand description
Job scheduling options.Beta Feature: These options are available for testing purposes only. They may be changed before final release.
This type is not used in any activity, and only used as part of another schema.
Fields
max_failures_per_hour: Option<i32>Optional. Maximum number of times per hour a driver may be restarted as a result of driver terminating with non-zero code before job is reported failed.A job may be reported as thrashing if driver exits with non-zero code 4 times within 10 minute window.Maximum value is 10.