Struct google_dataproc1::JobStatus
source · pub struct JobStatus {
pub state: Option<String>,
pub state_start_time: Option<String>,
pub details: Option<String>,
pub substate: Option<String>,
}Expand description
Cloud Dataproc job status.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>Output-only. A state message specifying the overall job state.
state_start_time: Option<String>Output-only. The time when this state was entered.
details: Option<String>Output-only. Optional job state details, such as an error description if the state is ERROR.
substate: Option<String>Output-only. Additional state information, which includes status reported by the agent.