Struct google_dataproc1::ListJobsResponse
source · pub struct ListJobsResponse {
pub next_page_token: Option<String>,
pub jobs: Option<Vec<Job>>,
}Expand description
A list of jobs in a project.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- regions jobs list projects (response)
Fields
next_page_token: Option<String>Optional. This token is included in the response if there are more results to fetch. To fetch additional results, provide this value as the page_token in a subsequent ListJobsRequest.
jobs: Option<Vec<Job>>Output-only. Jobs list.