Struct google_dataproc1::ManagedGroupConfig
source · pub struct ManagedGroupConfig {
pub instance_template_name: Option<String>,
pub instance_group_manager_name: Option<String>,
}Expand description
Specifies the resources used to actively manage an instance group.
This type is not used in any activity, and only used as part of another schema.
Fields
instance_template_name: Option<String>Output-only. The name of the Instance Template used for the Managed Instance Group.
instance_group_manager_name: Option<String>Output-only. The name of the Instance Group Manager for this group.