pub struct NodeInitializationAction {
pub execution_timeout: Option<String>,
pub executable_file: Option<String>,
}Expand description
Specifies an executable to run on a fully configured node and a timeout period for executable completion.
This type is not used in any activity, and only used as part of another schema.
Fields
execution_timeout: Option<String>Optional. Amount of time executable has to complete. Default is 10 minutes. Cluster creation fails with an explanatory error message (the name of the executable that caused the error and the exceeded timeout period) if the executable is not completed at end of the timeout period.
executable_file: Option<String>Required. Google Cloud Storage URI of executable file.