Struct google_dataproc1::PigJob
source · pub struct PigJob {
pub query_file_uri: Option<String>,
pub script_variables: Option<HashMap<String, String>>,
pub logging_config: Option<LoggingConfig>,
pub continue_on_failure: Option<bool>,
pub jar_file_uris: Option<Vec<String>>,
pub query_list: Option<QueryList>,
pub properties: Option<HashMap<String, String>>,
}Expand description
A Cloud Dataproc job for running Apache Pig (https://pig.apache.org/) queries on YARN.
This type is not used in any activity, and only used as part of another schema.
Fields
query_file_uri: Option<String>The HCFS URI of the script that contains the Pig queries.
script_variables: Option<HashMap<String, String>>Optional. Mapping of query variable names to values (equivalent to the Pig command: name=[value]).
logging_config: Option<LoggingConfig>Optional. The runtime log config for job execution.
continue_on_failure: Option<bool>Optional. Whether to continue executing queries if a query fails. The default value is false. Setting to true can be useful when executing independent parallel queries.
jar_file_uris: Option<Vec<String>>Optional. HCFS URIs of jar files to add to the CLASSPATH of the Pig Client and Hadoop MapReduce (MR) tasks. Can contain Pig UDFs.
query_list: Option<QueryList>A list of queries.
properties: Option<HashMap<String, String>>Optional. A mapping of property names to values, used to configure Pig. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/hadoop/conf/*-site.xml, /etc/pig/conf/pig.properties, and classes in user code.