Struct google_dataproc1::SoftwareConfig
source · pub struct SoftwareConfig {
pub image_version: Option<String>,
pub properties: Option<HashMap<String, String>>,
}Expand description
Specifies the selection and config of software inside the cluster.
This type is not used in any activity, and only used as part of another schema.
Fields
image_version: Option<String>Optional. The version of software inside the cluster. It must match the regular expression [0-9]+.[0-9]+. If unspecified, it defaults to the latest version (see Cloud Dataproc Versioning).
properties: Option<HashMap<String, String>>Optional. The properties to set on daemon config files.Property keys are specified in prefix:property format, such as core:fs.defaultFS. The following are supported prefixes and their mappings: capacity-scheduler: capacity-scheduler.xml core: core-site.xml distcp: distcp-default.xml hdfs: hdfs-site.xml hive: hive-site.xml mapred: mapred-site.xml pig: pig.properties spark: spark-defaults.conf yarn: yarn-site.xml