Struct google_dataproc1::SubmitJobRequest
source · pub struct SubmitJobRequest {
pub job: Option<Job>,
}Expand description
A request to submit a job.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- regions jobs submit projects (request)
Fields
job: Option<Job>Required. The job resource.