Struct google_dataproc1::Cluster
source · pub struct Cluster {
pub status: Option<ClusterStatus>,
pub cluster_uuid: Option<String>,
pub cluster_name: Option<String>,
pub project_id: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub metrics: Option<ClusterMetrics>,
pub status_history: Option<Vec<ClusterStatus>>,
pub config: Option<ClusterConfig>,
}Expand description
Describes the identifying information, config, and status of a cluster of Google Compute Engine instances.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- regions clusters patch projects (request)
- regions clusters create projects (request)
- regions clusters get projects (response)
Fields
status: Option<ClusterStatus>Output-only. Cluster status.
cluster_uuid: Option<String>Output-only. A cluster UUID (Unique Universal Identifier). Cloud Dataproc generates this value when it creates the cluster.
cluster_name: Option<String>Required. The cluster name. Cluster names within a project must be unique. Names of deleted clusters can be reused.
project_id: Option<String>Required. The Google Cloud Platform project ID that the cluster belongs to.
labels: Option<HashMap<String, String>>Optional. The labels to associate with this cluster. Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt). Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt). No more than 32 labels can be associated with a cluster.
metrics: Option<ClusterMetrics>Contains cluster daemon metrics such as HDFS and YARN stats.Beta Feature: This report is available for testing purposes only. It may be changed before final release.
status_history: Option<Vec<ClusterStatus>>Output-only. The previous cluster status.
config: Option<ClusterConfig>Required. The cluster config. Note that Cloud Dataproc may set default values, and values may change when clusters are updated.