Struct google_dataproc1::InstanceGroupConfig
source · pub struct InstanceGroupConfig {
pub is_preemptible: Option<bool>,
pub machine_type_uri: Option<String>,
pub instance_names: Option<Vec<String>>,
pub disk_config: Option<DiskConfig>,
pub accelerators: Option<Vec<AcceleratorConfig>>,
pub managed_group_config: Option<ManagedGroupConfig>,
pub num_instances: Option<i32>,
pub image_uri: Option<String>,
}Expand description
Optional. The config settings for Google Compute Engine resources in an instance group, such as a master or worker group.
This type is not used in any activity, and only used as part of another schema.
Fields
is_preemptible: Option<bool>Optional. Specifies that this instance group contains preemptible instances.
machine_type_uri: Option<String>Required. The Google Compute Engine machine type used for cluster instances. Example: https://www.googleapis.com/compute/v1/projects/[project_id]/zones/us-east1-a/machineTypes/n1-standard-2.
instance_names: Option<Vec<String>>Optional. The list of instance names. Cloud Dataproc derives the names from cluster_name, num_instances, and the instance group if not set by user (recommended practice is to let Cloud Dataproc derive the name).
disk_config: Option<DiskConfig>Optional. Disk option config settings.
accelerators: Option<Vec<AcceleratorConfig>>Optional. The Google Compute Engine accelerator configuration for these instances.Beta Feature: This feature is still under development. It may be changed before final release.
managed_group_config: Option<ManagedGroupConfig>Output-only. The config for Google Compute Engine Instance Group Manager that manages this group. This is only used for preemptible instance groups.
num_instances: Option<i32>Required. The number of VM instances in the instance group. For master instance groups, must be set to 1.
image_uri: Option<String>Output-only. The Google Compute Engine image resource used for cluster instances. Inferred from SoftwareConfig.image_version.