Struct google_dataproc1::PySparkJob
source · pub struct PySparkJob {
pub main_python_file_uri: Option<String>,
pub jar_file_uris: Option<Vec<String>>,
pub logging_config: Option<LoggingConfig>,
pub args: Option<Vec<String>>,
pub file_uris: Option<Vec<String>>,
pub archive_uris: Option<Vec<String>>,
pub python_file_uris: Option<Vec<String>>,
pub properties: Option<HashMap<String, String>>,
}Expand description
A Cloud Dataproc job for running Apache PySpark (https://spark.apache.org/docs/0.9.0/python-programming-guide.html) applications on YARN.
This type is not used in any activity, and only used as part of another schema.
Fields
main_python_file_uri: Option<String>Required. The HCFS URI of the main Python file to use as the driver. Must be a .py file.
jar_file_uris: Option<Vec<String>>Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Python driver and tasks.
logging_config: Option<LoggingConfig>Optional. The runtime log config for job execution.
args: Option<Vec<String>>Optional. The arguments to pass to the driver. Do not include arguments, such as –conf, that can be set as job properties, since a collision may occur that causes an incorrect job submission.
file_uris: Option<Vec<String>>Optional. HCFS URIs of files to be copied to the working directory of Python drivers and distributed tasks. Useful for naively parallel tasks.
archive_uris: Option<Vec<String>>Optional. HCFS URIs of archives to be extracted in the working directory of .jar, .tar, .tar.gz, .tgz, and .zip.
python_file_uris: Option<Vec<String>>Optional. HCFS file URIs of Python files to pass to the PySpark framework. Supported file types: .py, .egg, and .zip.
properties: Option<HashMap<String, String>>Optional. A mapping of property names to values, used to configure PySpark. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code.