Struct google_dataproc1::WorkflowTemplate [−][src]
pub struct WorkflowTemplate {
pub update_time: Option<String>,
pub jobs: Option<Vec<OrderedJob>>,
pub name: Option<String>,
pub parameters: Option<Vec<TemplateParameter>>,
pub labels: Option<HashMap<String, String>>,
pub id: Option<String>,
pub version: Option<i32>,
pub placement: Option<WorkflowTemplatePlacement>,
pub create_time: Option<String>,
}A Cloud Dataproc workflow template resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations workflow templates create projects (request|response)
- regions workflow templates create projects (request|response)
- regions workflow templates instantiate inline projects (request)
- regions workflow templates update projects (request|response)
- locations workflow templates instantiate inline projects (request)
- locations workflow templates get projects (response)
- locations workflow templates update projects (request|response)
- regions workflow templates get projects (response)
Fields
update_time: Option<String>
Output only. The time template was last updated.
jobs: Option<Vec<OrderedJob>>
Required. The Directed Acyclic Graph of Jobs to submit.
name: Option<String>
Output only. The "resource name" of the template, as described in https://cloud.google.com/apis/design/resource_names of the form projects/{project_id}/regions/{region}/workflowTemplates/{template_id}
parameters: Option<Vec<TemplateParameter>>
Optional. Template parameters whose values are substituted into the template. Values for parameters must be provided when the template is instantiated.
labels: Option<HashMap<String, String>>
Optional. The labels to associate with this template. These labels will be propagated to all jobs and clusters created by the workflow instance.Label keys must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt).Label values may be empty, but, if present, must contain 1 to 63 characters, and must conform to RFC 1035 (https://www.ietf.org/rfc/rfc1035.txt).No more than 32 labels can be associated with a template.
id: Option<String>
Required. The template id.The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between 3 and 50 characters.
version: Option<i32>
Optional. Used to perform a consistent read-modify-write.This field should be left blank for a CreateWorkflowTemplate request. It is required for an UpdateWorkflowTemplate request, and must match the current server version. A typical update template flow would fetch the current template with a GetWorkflowTemplate request, which will return the current template with the version field filled in with the current server version. The user updates other fields in the template, then returns it as part of the UpdateWorkflowTemplate request.
placement: Option<WorkflowTemplatePlacement>
Required. WorkflowTemplate scheduling information.
create_time: Option<String>
Output only. The time template was created.